from django.contrib import admin
from django.utils.html import format_html

class QRCodeAdminMixin(admin.ModelAdmin):

    def qrcode_thumbnail(self, obj):
        return format_html("<img src='%s' style='height:32px; width='32px' />" % obj.qrcode.url)

    def get_list_display(self, request):
        list_display = super(QRCodeAdminMixin, self).get_list_display(request)
        return ['qrcode_thumbnail'] + list_display


import io
import uuid
import qrcode
from django.db import models
from django.core.files import File


class QRCodeMixin(models.Model):
    class Meta:
        abstract = True

    qr_version = 1
    qr_error_correction = qrcode.constants.ERROR_CORRECT_L
    qr_box_size = 10
    qr_border = 4
    qrcode = models.ImageField(upload_to='qrcode', blank=True, null=True, editable=False)

    def get_qrcode_data(self):
        return self.id

    def get_qrcode_filename(self):
        return "%s_%s_%s.png" % (self._meta.app_label, self._meta.model_name, self.pk or uuid.uuid4())

    def make_image(self):
        qr = qrcode.QRCode(
            version=self.qr_version,
            error_correction=self.qr_error_correction,
            box_size=self.qr_box_size,
            border=self.qr_border
        )
        qr.add_data(self.get_qrcode_data())
        return qr.make_image()

    def generate_qrcode(self):
        stream = io.BytesIO()
        self.make_image().save(stream, format='PNG')
        self.qrcode.save(self.get_qrcode_filename(), File(stream), save=False)
        stream.close()

    def save(self, *args, **kwargs):
        if not self.qrcode:
            self.generate_qrcode()
        super().save(*args, **kwargs)

    def delete(self, using=None, keep_parents=False):
        self.qrcode.delete(save=False)
        super().delete(using=using, keep_parents=keep_parents)



#!/usr/bin/env python

import os
from setuptools import setup
from django_qrcodes import __version__


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='django-qrcodes',
    version=__version__,
    description='Django qrcode integration',
    long_description=long_description,
    long_description_content_type="text/markdown",
    maintainer='Rizki Sasri Dwitama',
    maintainer_email='sasri.project@gmail.com',
    license="MIT",
    url='https://github.com/sasriawesome/django_numerators',
    packages=[
        'django_qrcodes',
        'django_qrcodes.migrations',
        'django_qrcodes.utils',
    ],
    install_requires=[
        'Django',
        'qrcode',
        'Pillow',
    ],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)



# This file is heavily inspired by django.utils.version


def get_version(version):
    """Return a PEP 440-compliant version number from VERSION."""
    version = get_complete_version(version)

    # Now build the two parts of the version number:
    # main = X.Y[.Z]
    # sub = .devN - for pre-alpha releases
    #     | {a|b|rc}N - for alpha, beta, and rc releases

    main = get_main_version(version)

    sub = ''
    if version[3] != 'final':
        mapping = {'alpha': 'a', 'beta': 'b', 'rc': 'rc', 'dev': '.dev'}
        sub = mapping[version[3]] + str(version[4])

    return main + sub


def get_main_version(version=None):
    """Return main version (X.Y[.Z]) from VERSION."""
    version = get_complete_version(version)
    parts = 2 if version[2] == 0 else 3
    return '.'.join(str(x) for x in version[:parts])


def get_complete_version(version=None):
    """
    Return a tuple of the Wagtail version. If version argument is non-empty,
    check for correctness of the tuple provided.
    """
    if version is None:
        from wagtail import VERSION as version
    else:
        assert len(version) == 5
        assert version[3] in ('dev', 'alpha', 'beta', 'rc', 'final')

    return version


def get_semver_version(version):
    "Returns the semver version (X.Y.Z[-(alpha|beta)]) from VERSION"
    main = '.'.join(str(x) for x in version[:3])

    sub = ''
    if version[3] != 'final':
        sub = '-{}.{}'.format(*version[3:])
    return main + sub


from django_qrcodes.utils.version import get_version

default_app_config = 'django_qrcodes.apps.AppConfig'

# major.minor.patch.release.number
# release must be one of alpha, beta, rc, or final
VERSION = (0, 0, 1, 'final', 1)

__version__ = get_version(VERSION)
